from os.path import join
from os import makedirs, environ
from pathlib import Path
import logging
from dotenv import dotenv_values, load_dotenv
from io import StringIO

logging.basicConfig(level=logging.INFO)
LOG = logging.getLogger(__name__)
LOCAL_DIR = join(Path.home(), ".pygadget")


def try_make_dirs(directory):
    try:
        makedirs(directory)
    except OSError:
        LOG.info(f"{directory} already exists. skipping.")
    except Exception as e:
        raise RuntimeError(f"unhandled exceptions {str(e)}")
    else:
        LOG.info(".pygadget dir created")


try_make_dirs(LOCAL_DIR)
try_make_dirs(join(LOCAL_DIR, "data"))

try:
    env = dotenv_values(stream=StringIO(open(join(LOCAL_DIR, ".env"), "r").read()))
    LOG.info("loaded vars from .env")
except OSError:
    env = {k: v for k, v in environ.items() if k.startswith("PYGADGETS")}
    LOG.info("loaded vars from environ")


if env == {}:
    raise RuntimeError("Unable to collect configuration vars")

config = type("Config", (), env)



# A. Fair Playoff
# time limit per test
# 2 seconds
# memory limit per test
# 256 megabytes
# input
# standard input
# output
# standard output

# Four players participate in the playoff tournament. The tournament is held according to the following scheme: the first player will play with the second, and the third player with the fourth, then the winners of the pairs will play in the finals of the tournament.

# It is known that in a match between two players, the one whose skill is greater will win. The skill of the i
# -th player is equal to si and all skill levels are pairwise different (i. e. there are no two identical values in the array s

# ).

# The tournament is called fair if the two players with the highest skills meet in the finals.

# Determine whether the given tournament is fair.
# Input

# The first line contains a single integer t
# (1≤t≤104

# ) — the number of test cases.

# A single line of test case contains four integers s1,s2,s3,s4
# (1≤si≤100

# ) — skill of the players. It is guaranteed that all the numbers in the array are different.
# Output

# For each testcase, output YES if the tournament is fair, or NO otherwise.
# Example
# Input
# Copy

# 4
# 3 7 9 5
# 4 5 6 9
# 5 3 8 1
# 6 5 3 2

# Output
# Copy

# YES
# NO
# YES
# NO
def main():
    n = int(input())

    for _ in range(n):
        skills = [int(i) for i in input().split()]
        p1, p2 = skills[:2], skills[2:]
        # 3 7 9 5 -> 9 and 5 advance -> YES
        # 4 5 6 9 -> NO -> 6 does not advance
        best = sorted(skills, reverse=True)[:2]
        if (set(p1) == set(best)) or (set(p2) == set(best)):
            print("NO")
        else:
            print("YES")


if __name__ == "__main__":
    main()



import sys
import logging
from .svc import CeidgService

log = logging.getLogger(__name__)

if __name__ == "__main__":
    try:
        cei = CeidgService()
        args = sys.argv[1:]
        if "--dump" in args:
            numpages = None
            if "--num" in args:
                numpages = int(args[2])
            cei.prepare_dump(numpages, clear=False)
    except KeyboardInterrupt:
        log.info("interrupted by the user. exiting.")
        sys.exit(1)



from os import stat
from os import listdir, remove
from . import LOCAL_DIR, join, Path
from .ext.ceidg import iter_pages
from .util import lazyproperty
import pickle
import logging

log = logging.getLogger(__name__)


def _dump_pages(numpages=None):
    log.info("dumping companies")
    pages = iter_pages(numpages, expand=True)
    for ix, page in enumerate(pages):
        with open(join(LOCAL_DIR, "data", "co_page_" + str(ix) + ".pkl"), "wb") as f:
            log.info(f"dumping page {ix} of length {len(page)}")
            pickle.dump(page, f)


class CeidgService:
    @property
    def datafiles(self):
        return [
            join(LOCAL_DIR, "data", f)
            for f in listdir(str(LOCAL_DIR) + "/data")
            if "_page_" in f
        ]

    @lazyproperty
    def pages(self):
        _pages = []
        for pkl in self.datafiles:
            with open(pkl, "rb") as f:
                records = pickle.load(f)
                _pages.append(records)
        return _pages

    def prepare_dump(self, numpages=None, clear=False):
        for f in self.datafiles:
            if clear:
                log.info(f"removing {f}")
                remove(f)
        _dump_pages(numpages)

    def list_companies(self):
        return [co for page in self.pages for co in page]

    def filter_by_name(self, name):
        return [
            co
            for co in self.list_companies()
            if co.name.lower().strip() == name.lower()
        ]



# A. Bit++
# time limit per test
# 1 second
# memory limit per test
# 256 megabytes
# input
# standard input
# output
# standard output

# The classic programming language of Bitland is Bit++. This language is so peculiar and complicated.

# The language is that peculiar as it has exactly one variable, called x. Also, there are two operations:

#     Operation ++ increases the value of variable x by 1.
#     Operation -- decreases the value of variable x by 1.

# A statement in language Bit++ is a sequence, consisting of exactly one operation and one variable x. The statement is written without spaces, that is, it can only contain characters "+", "-", "X". Executing a statement means applying the operation it contains.

# A programme in Bit++ is a sequence of statements, each of them needs to be executed. Executing a programme means executing all the statements it contains.

# You're given a programme in language Bit++. The initial value of x is 0. Execute the programme and find its final value (the value of the variable when this programme is executed).
# Input

# The first line contains a single integer n (1 ≤ n ≤ 150) — the number of statements in the programme.

# Next n lines contain a statement each. Each statement contains exactly one operation (++ or --) and exactly one variable x (denoted as letter «X»). Thus, there are no empty statements. The operation and the variable can be written in any order.
# Output

# Print a single integer — the final value of x.
# Examples
# Input
# Copy

# 1
# ++X

# Output
# Copy

# 1

# Input
# Copy

# 2
# X++
# --X

# Output
# Copy

# 0
def main():
    X = 0

    n = int(input())

    for _ in range(n):
        expr = str(input())

        if "++" in expr:
            X += 1
        elif "--" in expr:
            X -= 1

    print(X)


if __name__ == "__main__":
    main()



import requests
from requests.adapters import HTTPAdapter
from pygadgets import config
from dataclasses import dataclass
import logging
import time


BASEURL = "https://dane.biznes.gov.pl/api/ceidg/v1"

headers = {"Authorization": "Bearer " + config.PYGADGETS_CEIDG_API_TOKEN}

log = logging.getLogger(__name__)

_session = None
MAX_RETRIES = 3


class RequestError(Exception):
    pass


@dataclass
class Company:
    name: str
    address: dict
    status: str
    url: str
    details: dict


def get_session():
    global _session

    if _session is not None:
        log.debug("using cached session")
        return _session

    session = requests.Session()
    session.headers.update(headers)
    session.mount(prefix=BASEURL, adapter=HTTPAdapter(max_retries=MAX_RETRIES))
    _session = session
    return session


def make_request(query):
    time.sleep(0.1)
    log.info(f"making request: {query}")
    res = get_session().get(query)
    if res.status_code == 200:
        return res.json()
    else:
        raise RequestError(f"unable to make a request {str(res)}")


def get_page(num_page=1):
    url = BASEURL + f"/firmy?limit=50&page={num_page}".format(str(num_page))
    return make_request(url)


def expand_details(co):
    co.details = make_request(co.url)["firma"]
    return co


def prepare(raw_page, expand=False):
    companies = []
    for co in raw_page:
        c = Company(co["nazwa"], co["adresDzialanosci"], co["status"], co["link"], None)
        if expand:
            c = expand_details(c)
        companies.append(c)
    return companies


def iter_pages(numpages=None, expand=False, start_page=1):
    pagecount = 0
    page = get_page(start_page)
    while True:
        try:
            log.info(f"getting page {pagecount}")
            prepared = prepare(page["firmy"], expand)
            yield prepared
            next_link = page["links"]["next"]
            log.debug(f"next link {next_link}")
            page = make_request(next_link)
        except Exception as e:
            log.info(f"cannot get next page. ending. {str(e)}")
            break
        else:
            pagecount += 1
            if numpages and (pagecount >= numpages):
                log.info("maxpage reached. ending.")
                break



import pytest

from pygadgets.svc import CeidgService


@pytest.fixture
def ceidg():
    return CeidgService()


def test_can_dump_to_datafiles(ceidg):
    ceidg.prepare_dump(numpages=1, clear=True)
    assert len(ceidg.datafiles) == 1
    

def test_can_list_datafiles(ceidg):
    assert len(ceidg.datafiles) > 0


def test_can_read_from_datafiles(ceidg):
    assert len(ceidg.pages) > 0


def test_can_list_companies_from_datafiles(ceidg):
    companies = ceidg.list_companies()
    assert len(companies) == 50



    


import logging


log = logging.getLogger(__name__)


class lazyproperty:
    def __init__(self, func):
        self.func = func

    def __get__(self, instance, cls):
        if instance is None:
            return self
        else:
            value = self.func(instance)
            setattr(instance, self.func.__name__, value)
            return value



from pygadgets.ext.ceidg import get_page, iter_pages
import pytest


# @pytest.mark.skip('skip for now')
def test_get_page():
    assert len(get_page()['firmy']) == 50

def test_iter_pages():
    pages = list(iter_pages(2))
    assert len(pages) == 2
    assert pages[0][0].details is None

def test_iter_pages_expanded():
    pages = list(iter_pages(numpages=1, expand=True))
    assert len(pages) == 1
    assert pages[0][0].details is not None







# A. Boy or Girl
# time limit per test
# 1 second
# memory limit per test
# 256 megabytes
# input
# standard input
# output
# standard output

# Those days, many boys use beautiful girls' photos as avatars in forums. So it is pretty hard to tell the gender of a user at the first glance. Last year, our hero went to a forum and had a nice chat with a beauty (he thought so). After that they talked very often and eventually they became a couple in the network.

# But yesterday, he came to see "her" in the real world and found out "she" is actually a very strong man! Our hero is very sad and he is too tired to love again now. So he came up with a way to recognize users' genders by their user names.

# This is his method: if the number of distinct characters in one's user name is odd, then he is a male, otherwise she is a female. You are given the string that denotes the user name, please help our hero to determine the gender of this user by his method.
# Input

# The first line contains a non-empty string, that contains only lowercase English letters — the user name. This string contains at most 100 letters.
# Output

# If it is a female by our hero's method, print "CHAT WITH HER!" (without the quotes), otherwise, print "IGNORE HIM!" (without the quotes).
# Examples
# Input
# Copy

# wjmzbmr

# Output
# Copy

# CHAT WITH HER!

# Input
# Copy

# xiaodao

# Output
# Copy

# IGNORE HIM!

# Input
# Copy

# sevenkplus

# Output
# Copy

# CHAT WITH HER!

# Note

# For the first example. There are 6 distinct characters in "wjmzbmr". These characters are: "w", "j", "m", "z", "b", "r". So wjmzbmr is a female and you should print "CHAT WITH HER!".
def main():
    n = str(input())

    if len(set(n)) % 2 == 0:
        print("CHAT WITH HER!")
    else:
        print("IGNORE HIM!")


if __name__ == "__main__":
    main()



# A. Way Too Long Words
# time limit per test
# 1 second
# memory limit per test
# 256 megabytes
# input
# standard input
# output
# standard output

# Sometimes some words like "localization" or "internationalization" are so long that writing them many times in one text is quite tiresome.

# Let's consider a word too long,
# if its length is strictly more than 10 characters.
# All too long words should be replaced with a special abbreviation.

# This abbreviation is made like this: we write down the first and the last letter of a word and between them we write the number of letters between the first and the last letters. That number is in decimal system and doesn't contain any leading zeroes.

# Thus, "localization" will be spelt as "l10n", and "internationalization» will be spelt as "i18n".

# You are suggested to automatize the process of changing the words with abbreviations. At that all too long words should be replaced by the abbreviation and the words that are not too long should not undergo any changes.
# Input

# The first line contains an integer n (1 ≤ n ≤ 100). Each of the following n lines contains one word. All the words consist of lowercase Latin letters and possess the lengths of from 1 to 100 characters.
# Output

# Print n lines. The i-th line should contain the result of replacing of the i-th word from the input data.
# Examples
# Input
# Copy

# 4
# word
# localization
# internationalization
# pneumonoultramicroscopicsilicovolcanoconiosis

# Output
# Copy

# word
# l10n
# i18n
# p43s
def main():
    n = int(input())
    for i in range(int(n)):
        w = str(input())
        if len(w) > 10:
            print(w[0] + str(len(w[1:-1])) + w[-1])
        else:
            print(w)


if __name__ == "__main__":
    main()
